@@ -45,7 +45,7 @@ sub _new {
     my $class = ref($proto) || $proto;
     my %params = @_;
 
-    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is requried";
+    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is required";
     my $self;
     if (exists $params{name}) {
 	$self = Sys::Virt::Interface::_lookup_by_name($con,  $params{name});
@@ -102,6 +102,27 @@ completes and should not be used again.
 
 =head1 CONSTANTS
 
+=head1 CONSTANTS
+
+This section documents constants that are used with various
+APIs described above
+
+=head2 LIST FILTERING
+
+The following constants are used to filter object lists
+
+=over 4
+
+=item Sys::Virt::Interface::LIST_ACTIVE
+
+Include interfaces that are active
+
+=item Sys::Virt::Interface::LIST_INACTIVE
+
+Include interfaces that are not active
+
+=back
+
 =head2 XML CONSTANTS
 
 The following constants are used when querying XML
